[llvm-commits] CVS: llvm/lib/VMCore/AsmWriter.cpp

Chris Lattner lattner at cs.uiuc.edu
Thu Mar 11 23:55:26 PST 2004


Changes in directory llvm/lib/VMCore:

AsmWriter.cpp updated: 1.125 -> 1.126

---
Log message:

Print select instructions correctly


---
Diffs of the changes:  (+3 -2)

Index: llvm/lib/VMCore/AsmWriter.cpp
diff -u llvm/lib/VMCore/AsmWriter.cpp:1.125 llvm/lib/VMCore/AsmWriter.cpp:1.126
--- llvm/lib/VMCore/AsmWriter.cpp:1.125	Mon Mar  8 12:51:45 2004
+++ llvm/lib/VMCore/AsmWriter.cpp	Thu Mar 11 23:53:14 2004
@@ -915,8 +915,9 @@
     bool PrintAllTypes = false;
     const Type *TheType = Operand->getType();
 
-    // Shift Left & Right print both types even for Ubyte LHS
-    if (isa<ShiftInst>(I)) {
+    // Shift Left & Right print both types even for Ubyte LHS, and select prints
+    // types even if all operands are bools.
+    if (isa<ShiftInst>(I) || isa<SelectInst>(I)) {
       PrintAllTypes = true;
     } else {
       for (unsigned i = 1, E = I.getNumOperands(); i != E; ++i) {





More information about the llvm-commits mailing list